@@ -1,6 +1,6 @@
 /*
  * Cueplot: a GUI front-end to gnuplot
- * Copyright (C) 2007 Muneyuki Noguchi
+ * Copyright (C) 2007, 2008 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,12 +25,8 @@ class QString;
 class Command
 {
 	public:
-		Command()
-		{
-		}
-		virtual ~Command()
-		{
-		}
+		Command() { }
+		virtual ~Command() { }
 
 		/*!
 		 * \brief コマンド文字列を生成して返す
