@@ -1,6 +1,6 @@
 /*
  * Cueplot: a GUI front-end to gnuplot
- * Copyright (C) 2007 Muneyuki Noguchi
+ * Copyright (C) 2007, 2008 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,12 +25,8 @@ class QString;
 class CommandOption
 {
 	public:
-		CommandOption()
-		{
-		}
-		virtual ~CommandOption()
-		{
-		}
+		CommandOption() { }
+		virtual ~CommandOption() { }
 
 		virtual QString option() const = 0;
 };
